==> sql-generator-1.1.2-src.zip: sql-generator-1.1.2-src/src/org/sql/comparison/SubQueryComparison.java <==
/*
 * SQL Generator
 * 
 * Copyright (C) 2005 Satoshi Nagashiba, All Rights Reserved.
 */
package org.sql.comparison;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;

import org.sql.exception.ComparisonException;
import org.sql.exception.GeneratorException;
import org.sql.generator.SelectSql;
import org.sql.generator.Sql;
import org.sql.item.DefaultItem;
import org.sql.type.Match;


/**
 * TuNGɂǗNX.
 * <P>
 * r̐́ArIuWFNgbp[NX
 * i<a href="Comparisons.html">com.sn.sql.comparison.Comparisons</a>jgp܂B<br>
 * <br>
 * <ul>
 *     <li>TuNGݒ肷ꍇ<br>
 *     <br>
 *     <b>Java\[XTv</b><br>
 *     <table><tr><td class="SampleCode">
 *         j<font color="blue">SELECT * FROM TABLE1 WHERE COLUMN1 = (SELECT COLUMN2 FROM TABLE2 WHERE COLUMN2 = '')</font><br>
 *         <br>
 *         @SelectColumn column = new SelectColumn("COLUMN2");<br>
 *         <br>
 *         @Condition condition1 = new Condition();<br>
 *         @condition1.and(Comparisons.eq("COLUMN2", ""));<br>
 *         <br>
 *         @SelectSql subSql = new SelectSql("TABLE2", column, condition1);<br>
 *         <br>
 *         @Condition condition2 = new Condition();<br>
 *         @condition2.and(Comparisons.query("COLUMN1", subSql, Match.EQ));<br>
 *         <br>
 *         @SelectSql sql = new SelectSql("TABLE1", column, condition2);<br>
 *     </td></tr></table>
 * </ul>
 * <P>
 *
 * @author S.Nagashiba
 */
public class SubQueryComparison extends AbstractBindComparison {

	/** r@ */
	private Match match = null;
	
	/**
	 * RXgN^
	 * @param column J
	 * @param value  SQL
	 * @param match  r@
	 */
    public SubQueryComparison(String column, SelectSql value, Match match) {
        setComparison(column, value, match);
    }
	
	/**
	 * oChp[^擾
	 * @return oChp[^
	 */
	public Object[] getParameter() {
		List result = new ArrayList();
		Object[] parameter = super.getParameter();
		for (int i = 0; i < parameter.length; i++) {
			result.addAll(Arrays.asList(((Sql) parameter[i]).getParameter()));
		}
		return result.toArray();
	}

    /**
     * rݒ肷
     * @param column J
     * @param value  SQL
     * @param match  r@
     */
    protected void setComparison(String column, SelectSql value, Match match) {
       	DefaultItem item = new DefaultItem();
       	item.put(column, value);
        super.setComparison(item);
        this.match = match;
    }
    
	/**
	 * r쐬
	 * @param item ACe
	 * @return r
	 * @throws ComparisonException rO
	 */
	protected String createComparison(DefaultItem item) throws ComparisonException {
		return createComparison(item, false);
	}
	
	/**
	 * oChr쐬
	 * @param item ACe
	 * @return r
	 * @throws ComparisonException rO
	 */
	protected String createBindComparison(DefaultItem item) throws ComparisonException {
		return createComparison(item, true);
	}
	
	/**
	 * r쐬
	 * @param item ACe
	 * @param bind ߍ݌^SQL[true]AʏSQL[false]
	 * @return r
	 * @throws ComparisonException rO
	 */
	private String createComparison(DefaultItem item, boolean bind) throws ComparisonException {
		StringBuffer sb = new StringBuffer();
		Sql sql = (SelectSql) item.getValue()[0];
        try {
    		sb.append(item.getColumn());
    		sb.append(this.match.toTypeString());
    		sb.append("(");
    		sb.append(bind ? sql.getBindSql() : sql.getSql());
    		sb.append(")");
        }
        catch (GeneratorException e) {
            super.setException(e);
        }
		return sb.toString();
	}
}

==> sql-generator-1.1.3-src.zip: sql-generator-1.1.3-src/src/org/sql/comparison/SubQueryComparison.java <==
/*
 * SQL Generator
 * 
 * Copyright (C) 2005 Satoshi Nagashiba, All Rights Reserved.
 */
package org.sql.comparison;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;

import org.sql.exception.ComparisonException;
import org.sql.exception.GeneratorException;
import org.sql.generator.SelectSql;
import org.sql.generator.Sql;
import org.sql.item.DefaultItem;
import org.sql.type.Match;


/**
 * TuNGɂǗNX.
 * <P>
 * r̐́ArIuWFNgbp[NX
 * i<a href="Comparisons.html">com.sn.sql.comparison.Comparisons</a>jgp܂B<br>
 * <br>
 * <ul>
 *     <li>TuNGݒ肷ꍇ<br>
 *     <br>
 *     <b>Java\[XTv</b><br>
 *     <table><tr><td class="SampleCode">
 *         j<font color="blue">SELECT * FROM TABLE1 WHERE COLUMN1 = (SELECT COLUMN2 FROM TABLE2 WHERE COLUMN2 = '')</font><br>
 *         <br>
 *         @SelectColumn column = new SelectColumn("COLUMN2");<br>
 *         <br>
 *         @Condition condition1 = new Condition();<br>
 *         @condition1.and(Comparisons.eq("COLUMN2", ""));<br>
 *         <br>
 *         @SelectSql subSql = new SelectSql("TABLE2", column, condition1);<br>
 *         <br>
 *         @Condition condition2 = new Condition();<br>
 *         @condition2.and(Comparisons.query("COLUMN1", subSql, Match.EQ));<br>
 *         <br>
 *         @SelectSql sql = new SelectSql("TABLE1", column, condition2);<br>
 *     </td></tr></table>
 * </ul>
 * <P>
 *
 * @author <a href="mailto:nagashiba.satoshi@opcybe.co.jp">Satoshi Nagashiba</a>
 * @version $Revision: 1.11 $ $Date: 2006/04/08 08:48:16 $
 */
public class SubQueryComparison extends BaseBindComparison {

	/** r@ */
	private Match match = null;
	
	/**
	 * RXgN^
	 * @param column J
	 * @param value  SQL
	 * @param match  r@
	 */
    public SubQueryComparison(String column, SelectSql value, Match match) {
        setComparison(column, value, match);
    }
	
	/**
	 * oChp[^擾
	 * @return oChp[^
	 */
	public Object[] getParameter() {
		List result = new ArrayList();
		Object[] parameter = super.getParameter();
		for (int i = 0; i < parameter.length; i++) {
			result.addAll(Arrays.asList(((Sql) parameter[i]).getParameter()));
		}
		return result.toArray();
	}

    /**
     * rݒ肷
     * @param column J
     * @param value  SQL
     * @param match  r@
     */
    protected void setComparison(String column, SelectSql value, Match match) {
       	DefaultItem item = new DefaultItem();
       	item.put(column, value);
        super.setComparison(item);
        this.match = match;
    }
    
	/**
	 * r쐬
	 * @param item ACe
	 * @return r
	 * @throws ComparisonException rO
	 */
	protected String createComparison(DefaultItem item) throws ComparisonException {
		return createComparison(item, false);
	}
	
	/**
	 * oChr쐬
	 * @param item ACe
	 * @return r
	 * @throws ComparisonException rO
	 */
	protected String createBindComparison(DefaultItem item) throws ComparisonException {
		return createComparison(item, true);
	}
	
	/**
	 * r쐬
	 * @param item ACe
	 * @param bind ߍ݌^SQL[true]AʏSQL[false]
	 * @return r
	 * @throws ComparisonException rO
	 */
	private String createComparison(DefaultItem item, boolean bind) throws ComparisonException {
		StringBuffer sb = new StringBuffer();
		Sql sql = (SelectSql) item.getValue()[0];
        try {
    		sb.append(item.getColumn());
    		sb.append(this.match.toTypeString());
    		sb.append("(");
    		sb.append(bind ? sql.getBindSql() : sql.getSql());
    		sb.append(")");
        }
        catch (GeneratorException e) {
            super.setException(e);
        }
		return sb.toString();
	}
}
